==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/notify/translations/notify_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify about new messages only when window is inactive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore status changes from available / busy to busy / available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore changes right after connection to the server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This option will supersede tooltips with users&apos; status
 changes upon establishing connection to the server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify about all users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User changed status to online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User changed status to busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User changed status to invisible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User changed status to offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConnectionErrorNotification</name>
    <message>
        <source>Connection error</source>
        <translation type="unfinished">Erreur de connexion</translation>
    </message>
    <message>
        <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageNotification</name>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>Unable to find notifier for %1 event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to &apos;Notify list&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to &apos;User list&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusChangedNotification</name>
    <message>
        <source>Status changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.3.orig.tar.gz: kadu/modules/notify/translations/notify_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify about new messages only when window is inactive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore status changes from available / busy to busy / available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore changes right after connection to the server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This option will supersede tooltips with users&apos; status
 changes upon establishing connection to the server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify about all users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User changed status to online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User changed status to busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User changed status to invisible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User changed status to offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Silent Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Silent Mode when Away</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConnectionErrorNotification</name>
    <message>
        <source>Connection error</source>
        <translation type="unfinished">Erreur de connexion</translation>
    </message>
    <message>
        <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageNotification</name>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>Unable to find notifier for %1 event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to &apos;Notify list&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to &apos;User list&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Silent Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Silent Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusChangedNotification</name>
    <message>
        <source>Status changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
